/*
 *  Sshtools - Java SSH2 API
 *
 *  Copyright (C) 2002 Lee David Painter.
 *
 *  Written by: 2002 Lee David Painter <lee@sshtools.com>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package com.sshtools.j2ssh.transport;

import com.sshtools.j2ssh.io.ByteArrayReader;
import com.sshtools.j2ssh.io.ByteArrayWriter;

import java.io.IOException;


class SshMsgUnimplemented extends SshMessage {
    protected final static int SSH_MSG_UNIMPLEMENTED = 3;

    // The sequence no of the message
    private long sequenceNo;

    public SshMsgUnimplemented(long sequenceNo) {
        super(SSH_MSG_UNIMPLEMENTED);
        this.sequenceNo = sequenceNo;
    }

    public SshMsgUnimplemented() {
        super(SSH_MSG_UNIMPLEMENTED);
    }

    public String getMessageName() {
        return "SSH_MSG_UNIMPLEMENTED";
    }

    public long getSequenceNo() {
        return sequenceNo;
    }

    protected void constructByteArray(ByteArrayWriter baw)
        throws InvalidMessageException {
        try {
            baw.writeInt(sequenceNo);
        } catch (IOException ioe) {
            throw new InvalidMessageException(
                "Error extracting SSH_MSG_UNIMPLMENTED, expected int value");
        }
    }

    protected void constructMessage(ByteArrayReader bar)
        throws InvalidMessageException {
        try {
            sequenceNo = bar.readInt();
        } catch (IOException ioe) {
            throw new InvalidMessageException(
                "Error contructing SSH_MSG_UNIMPLEMENTED, expected int value");
        }
    }
}
